The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {GetTDData}


Title: Get Data for Brazilian Bonds (Tesouro Direto)
Version: 1.6.0
Description: Downloads and aggregates data for Brazilian government issued bonds directly from the website of Tesouro Direto https://www.tesourodireto.com.br/.
Depends: R (≥ 4.1.0)
Imports: stringr, readxl, utils, stats, curl, bizdays, tidyr, rvest, xml2, dplyr, fs, cli, jsonlite
License: MIT + file LICENSE
BugReports: https://github.com/msperlin/GetTDData/issues/
URL: https://github.com/msperlin/GetTDData/, https://msperlin.github.io/GetTDData/
Encoding: UTF-8
Suggests: knitr, rmarkdown, testthat, ggplot2, covr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-04 15:54:57 UTC; msperlin
Author: Marcelo Perlin [aut, cre]
Maintainer: Marcelo Perlin <marceloperlin@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-04 16:30:02 UTC

Returns the cache directory path

Description

Returns the cache directory path

Usage

get_cache_folder()

Value

A character string representing the folder path.

Examples

get_cache_folder()

Returns the available asset names at the Tesouro Direto (TD) website

Description

Returns the available asset names at the Tesouro Direto (TD) website

Usage

get_td_names()

Value

A character vector of names.

Examples

get_td_names()

Gets the current yield curve

Description

Downloads and parses information about the current Brazilian yield curve from Anbima.

Usage

get_yield_curve()

get.yield.curve()

Value

A data frame with information about the yield curve.

Examples

## Not run: 
df_yield <- get_yield_curve()
str(df_yield)

## End(Not run)

Downloads data for Brazilian government bonds directly from the website

Description

This function looks into the Tesouro Direto website (<https://www.tesourodireto.com.br/>) and downloads all files containing prices and yields of government bonds. You can use the input 'asset_codes' to restrict the downloads to specific bonds.

Usage

td_get(
  asset_codes = "LTN",
  first_year = 2005,
  last_year = as.numeric(format(Sys.Date(), "%Y")),
  dl_folder = get_cache_folder()
)

Arguments

asset_codes

A character vector identifying the assets (one or more) in the names of the Excel files (e.g., 'LTN'). If 'NULL', downloads all available assets.

first_year

The first year of data (minimum of 2005).

last_year

The last year of data.

dl_folder

Path of the folder to save Excel files from Tesouro Direto (will create if it does not exist). Defaults to a session-temporary directory. To avoid redownloading files across different R sessions, you can pass a persistent path (e.g., a local folder path, or using tools::R_user_dir("GetTDData", which = "cache")).

Value

A data frame containing the asset data (prices and yields).

Examples

## Not run: 
df_td <- td_get("LTN", 2020, 2022)

## End(Not run)

Returns current TD prices

Description

Fetches current prices of Tesouro Direto (TD) assets from the website's JSON API at <https://www.tesourodireto.com.br/titulos/precos-e-taxas.htm>.

Usage

td_get_current()

Value

A data frame with prices.

Examples

## Not run: 
df_current <- td_get_current()

## End(Not run)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.